Developer Guide
===============

Documentation is split general and topic-specific sections. Each section is split into four categories, and each is also accessible from links in the side-bar.

.. grid:: 2
    :gutter: 4

    .. grid-item-card:: :material-regular:`code;3em`

        .. toctree::
            :caption: General
            :maxdepth: 1

            general/index

        +++

        General information for working on mx-bluesky

    .. grid-item-card:: :material-outlined:`precision_manufacturing;3em`

        .. toctree::
            :caption: Hyperion
            :maxdepth: 1

            hyperion/index

        +++

        Documentation relating to hyperion

    .. grid-item-card:: :material-regular:`apps;3em`

        .. toctree::
            :caption: Serial Crystallography on I24
            :maxdepth: 1

            serial-crystallography-on-i24/index

        +++

        Documentation relating to serial crystallography on I24

    .. grid-item-card:: :material-outlined:`preview;3em`

        .. toctree::
            :caption: Murko Integration
            :maxdepth: 1

            murko-integration/index

        +++

        Documentation relating to integrating the murko image recognition system
